@@ -1,9 +1,10 @@
 import datetime
+import dns.resolver
 import json
 import logging
 import re
-import socket
 import xmltodict
+from urllib.parse import urlparse
 
 
 def convert_xml_to_dict(xml_string, json_output=False):
@@ -82,21 +83,36 @@ def is_ip_address(string_to_check):
     return False
 
 
-def resolve_dns(domain_name):
-    """Resolves the given domain name to an IP address.
+def resolve_dns(domain, dns_server=None, first_result_only=True):
+    """Resolves the domain to an IP address. If a DNS server is provided, it will use that server.
 
     Args:
-        domain_name (str): The domain name to resolve.
+        domain (str): The domain to resolve.
+        dns_server (str, optional): The DNS server to use. Defaults to None.
+        first_result_only (bool, optional): Whether to return only the first result. Defaults to True.
 
     Returns:
-        str: The resolved IP address.
-
-    Raises:
-        ValueError: If there is an error resolving the DNS.
+        str or list: The resolved IP address(es).
     """
-    try:
-        ip_address = socket.gethostbyname(domain_name)
-        return ip_address
+    # Check if the domain is a URL and extract the hostname
+    if domain.startswith("http"):
+        domain = urlparse(domain).hostname
 
-    except socket.gaierror as e:
-        raise ValueError(f"Error resolving DNS for {domain_name}: {e}")
+    # Initialize the resolver
+    resolver = dns.resolver.Resolver()
+
+    # Set the DNS server if provided
+    if dns_server:
+        resolver.nameservers = [dns_server]
+
+    try:
+        answer = resolver.resolve(domain)
+        # return the first result only if specified
+        if first_result_only:
+            return answer[0].to_text()
+
+        # otherwise return all results
+        return [rdata.to_text() for rdata in answer]
+
+    except (dns.resolver.NoAnswer, dns.resolver.NXDOMAIN, dns.exception.Timeout) as e:
+        return f"Error resolving DNS: {e}"
