@@ -1,6 +1,6 @@
 import unittest
 from unittest.mock import patch, MagicMock
-from bits_aviso_python_sdk.helpers import export_to_json
+from bits_aviso_python_sdk.helpers.files import write_json
 from bits_aviso_python_sdk.services.isilon import Isilon
 from bits_aviso_python_sdk.services.google.secretmanager import SecretManager
 
@@ -158,18 +158,18 @@ class TestIsilon(unittest.TestCase):
 def test():
     """Manually test the Isilon class."""
     secret_manager = SecretManager()
-    google_project = ''
-    credentials_secret = ''
-    clusters_secret = ''
+    google_project = 'bits-aviso-data-lake-dev'
+    credentials_secret = 'isilon-api'
+    clusters_secret = 'isilon-clusters'
     credentials = secret_manager.get_secret(google_project, credentials_secret)
     clusters = secret_manager.get_secret(google_project, clusters_secret)
     username = credentials.get('username')
     password = credentials.get('password')
-    isilon = Isilon(username, password, clusters)
-    quota_data, quota_error_data = isilon.get_all_quotas()
-    export_to_json(quota_data, 'quota_data.json')
-    network_pool_data, network_error_data = isilon.get_all_network_pools()
-    export_to_json(network_pool_data, 'network_pool_data.json')
+    isilon = Isilon(username, password, clusters, dns_resolve=True)
+    quota_data, _ = isilon.get_all_quotas()
+    write_json(quota_data, 'quota_data.json')
+    # network_pool_data, _ = isilon.get_all_network_pools()
+    # write_json(network_pool_data, 'network_pool_data.json')
 
 
 if __name__ == '__main__':
